@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 OpenStack Foundation
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -20,20 +18,28 @@ import os
 from paste import deploy
 
 from keystone.openstack.common import gettextutils
+# NOTE(dstanek): gettextutils.enable_lazy() must be called before
+# gettextutils._() is called to ensure it has the desired lazy lookup
+# behavior. This includes cases, like keystone.exceptions, where
+# gettextutils._() is called at import time.
+gettextutils.enable_lazy()
 
-# NOTE(blk-u):
-# gettextutils.install() must run to set _ before importing any modules that
-# contain static translated strings.
-gettextutils.install('keystone')
-
+from keystone.common import dependency
 from keystone.common import environment
+from keystone.common import sql
 from keystone import config
 from keystone.openstack.common import log
+from keystone import service
 
 
 CONF = config.CONF
+
+config.configure()
+sql.initialize()
+config.set_default_for_default_log_levels()
+
 CONF(project='keystone')
-config.setup_logging(CONF)
+config.setup_logging()
 
 environment.use_stdlib()
 name = os.path.basename(__file__)
@@ -41,8 +47,13 @@ name = os.path.basename(__file__)
 if CONF.debug:
     CONF.log_opt_values(log.getLogger(CONF.prog), logging.DEBUG)
 
+
+drivers = service.load_backends()
+
 # NOTE(ldbragst): 'application' is required in this context by WSGI spec.
 # The following is a reference to Python Paste Deploy documentation
 # http://pythonpaste.org/deploy/
 application = deploy.loadapp('config:%s' % config.find_paste_config(),
                              name=name)
+
+dependency.resolve_future_dependencies()
