@@ -1,4 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 # flake8: noqa
 
 # Copyright 2013 OpenStack Foundation
@@ -15,4 +14,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from keystone.assignment import controllers
 from keystone.assignment.core import *
+from keystone.assignment import routers
