@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,17 +12,21 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from keystone.common import dependency
+import abc
+
+import six
+
 from keystone import exception
 
 
-@dependency.requires('identity_api')
+@six.add_metaclass(abc.ABCMeta)
 class AuthMethodHandler(object):
     """Abstract base class for an authentication plugin."""
 
     def __init__(self):
         pass
 
+    @abc.abstractmethod
     def authenticate(self, context, auth_payload, auth_context):
         """Authenticate user and return an authentication context.
 
