@@ -19,26 +19,25 @@ import abc
 
 import six
 
-from keystone.common import cache
 from keystone.common import dependency
 from keystone.common import driver_hints
 from keystone.common import manager
+from keystone.common import utils
 from keystone import config
 from keystone import exception
-from keystone.i18n import _
-from keystone import notifications
+from keystone.openstack.common.gettextutils import _
 from keystone.openstack.common import log
 
 
 CONF = config.CONF
 LOG = log.getLogger(__name__)
-SHOULD_CACHE = cache.should_cache_fn('catalog')
-
-EXPIRATION_TIME = lambda: CONF.catalog.cache_time
 
 
 def format_url(url, data):
     """Safely string formats a user-defined URL with the given data."""
+    data = utils.WhiteListedFormatter(
+        CONF.catalog.endpoint_substitution_whitelist,
+        data)
     try:
         result = url.replace('$(', '%(') % data
     except AttributeError:
@@ -51,10 +50,10 @@ def format_url(url, data):
                    "keyerror": e})
         raise exception.MalformedEndpoint(endpoint=url)
     except TypeError as e:
-        LOG.error(_("Malformed endpoint '%(url)s'. The following type error "
-                    "occurred during string substitution: %(typeerror)s"),
+        LOG.error(_("Malformed endpoint %(url)s - unknown key %(keyerror)s"
+                    "(are you missing brackets ?)"),
                   {"url": url,
-                   "typeerror": e})
+                   "keyerror": e})
         raise exception.MalformedEndpoint(endpoint=url)
     except ValueError as e:
         LOG.error(_("Malformed endpoint %s - incomplete format "
@@ -71,7 +70,6 @@ class Manager(manager.Manager):
     dynamically calls the backend.
 
     """
-    _ENDPOINT = 'endpoint'
 
     def __init__(self):
         super(Manager, self).__init__(CONF.catalog.driver)
@@ -86,18 +84,12 @@ class Manager(manager.Manager):
             msg = _('Duplicate ID, %s.') % region_ref['id']
             raise exception.Conflict(type='region', details=msg)
 
-        # NOTE(lbragstad): The description column of the region database
-        # can not be null. So if the user doesn't pass in a description then
-        # set it to an empty string.
-        region_ref.setdefault('description', '')
         try:
             return self.driver.create_region(region_ref)
         except exception.NotFound:
             parent_region_id = region_ref.get('parent_region_id')
             raise exception.RegionNotFound(region_id=parent_region_id)
 
-    @cache.on_arguments(should_cache_fn=SHOULD_CACHE,
-                        expiration_time=EXPIRATION_TIME)
     def get_region(self, region_id):
         try:
             return self.driver.get_region(region_id)
@@ -106,9 +98,7 @@ class Manager(manager.Manager):
 
     def delete_region(self, region_id):
         try:
-            ret = self.driver.delete_region(region_id)
-            self.get_region.invalidate(self, region_id)
-            return ret
+            return self.driver.delete_region(region_id)
         except exception.NotFound:
             raise exception.RegionNotFound(region_id=region_id)
 
@@ -116,8 +106,6 @@ class Manager(manager.Manager):
         service_ref.setdefault('enabled', True)
         return self.driver.create_service(service_id, service_ref)
 
-    @cache.on_arguments(should_cache_fn=SHOULD_CACHE,
-                        expiration_time=EXPIRATION_TIME)
     def get_service(self, service_id):
         try:
             return self.driver.get_service(service_id)
@@ -126,13 +114,7 @@ class Manager(manager.Manager):
 
     def delete_service(self, service_id):
         try:
-            endpoints = self.list_endpoints()
-            ret = self.driver.delete_service(service_id)
-            self.get_service.invalidate(self, service_id)
-            for endpoint in endpoints:
-                if endpoint['service_id'] == service_id:
-                    self.get_endpoint.invalidate(self, endpoint['id'])
-            return ret
+            return self.driver.delete_service(service_id)
         except exception.NotFound:
             raise exception.ServiceNotFound(service_id=service_id)
 
@@ -147,17 +129,12 @@ class Manager(manager.Manager):
             service_id = endpoint_ref.get('service_id')
             raise exception.ServiceNotFound(service_id=service_id)
 
-    @notifications.deleted(_ENDPOINT, public=False)
     def delete_endpoint(self, endpoint_id):
         try:
-            ret = self.driver.delete_endpoint(endpoint_id)
-            self.get_endpoint.invalidate(self, endpoint_id)
-            return ret
+            return self.driver.delete_endpoint(endpoint_id)
         except exception.NotFound:
             raise exception.EndpointNotFound(endpoint_id=endpoint_id)
 
-    @cache.on_arguments(should_cache_fn=SHOULD_CACHE,
-                        expiration_time=EXPIRATION_TIME)
     def get_endpoint(self, endpoint_id):
         try:
             return self.driver.get_endpoint(endpoint_id)
@@ -190,7 +167,7 @@ class Driver(object):
         :raises: keystone.exception.RegionNotFound (if parent region invalid)
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def list_regions(self):
@@ -199,7 +176,7 @@ class Driver(object):
         :returns: list of region_refs or an empty list.
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def get_region(self, region_id):
@@ -209,7 +186,7 @@ class Driver(object):
         :raises: keystone.exception.RegionNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def update_region(self, region_id):
@@ -219,7 +196,7 @@ class Driver(object):
         :raises: keystone.exception.RegionNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def delete_region(self, region_id):
@@ -228,7 +205,7 @@ class Driver(object):
         :raises: keystone.exception.RegionNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def create_service(self, service_id, service_ref):
@@ -237,20 +214,16 @@ class Driver(object):
         :raises: keystone.exception.Conflict
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
-    def list_services(self, hints):
+    def list_services(self):
         """List all services.
 
-        :param hints: contains the list of filters yet to be satisfied.
-                      Any filters satisfied here will be removed so that
-                      the caller will know if any filters remain.
-
         :returns: list of service_refs or an empty list.
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def get_service(self, service_id):
@@ -260,7 +233,7 @@ class Driver(object):
         :raises: keystone.exception.ServiceNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def update_service(self, service_id):
@@ -270,7 +243,7 @@ class Driver(object):
         :raises: keystone.exception.ServiceNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def delete_service(self, service_id):
@@ -279,7 +252,7 @@ class Driver(object):
         :raises: keystone.exception.ServiceNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def create_endpoint(self, endpoint_id, endpoint_ref):
@@ -289,7 +262,7 @@ class Driver(object):
                  keystone.exception.ServiceNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def get_endpoint(self, endpoint_id):
@@ -299,20 +272,16 @@ class Driver(object):
         :raises: keystone.exception.EndpointNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
-    def list_endpoints(self, hints):
+    def list_endpoints(self):
         """List all endpoints.
 
-        :param hints: contains the list of filters yet to be satisfied.
-                      Any filters satisfied here will be removed so that
-                      the caller will know if any filters remain.
-
         :returns: list of endpoint_refs or an empty list.
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def update_endpoint(self, endpoint_id, endpoint_ref):
@@ -323,7 +292,7 @@ class Driver(object):
                  keystone.exception.ServiceNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def delete_endpoint(self, endpoint_id):
@@ -332,7 +301,7 @@ class Driver(object):
         :raises: keystone.exception.EndpointNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def get_catalog(self, user_id, tenant_id, metadata=None):
@@ -357,7 +326,7 @@ class Driver(object):
         :raises: keystone.exception.NotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     def get_v3_catalog(self, user_id, tenant_id, metadata=None):
         """Retrieve and format the current V3 service catalog.
