@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2012 OpenStack LLC
+# Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -16,6 +14,8 @@
 
 import json
 
+import six
+
 from sqlalchemy import MetaData, Table
 from sqlalchemy.orm import sessionmaker
 
@@ -27,7 +27,8 @@ def is_enabled(enabled):
     # no explicit value means enabled
     if enabled is True or enabled is None:
         return True
-    if isinstance(enabled, basestring) and enabled.lower() in DISABLED_VALUES:
+    if (isinstance(enabled, six.string_types)
+            and enabled.lower() in DISABLED_VALUES):
         return False
     return bool(enabled)
 
