@@ -1,7 +1,5 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2012 OpenStack LLC
-# Copyright 2013 IBM
+# Copyright 2012 OpenStack Foundation
+# Copyright 2013 IBM Corp.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -39,11 +37,11 @@ of integrity constraints.
 
 import sqlalchemy as sql
 from sqlalchemy.orm import sessionmaker
+
 from keystone import config
 
 
 CONF = config.CONF
-DEFAULT_DOMAIN_ID = CONF.identity.default_domain_id
 
 
 def _disable_foreign_constraints(session, migrate_engine):
@@ -94,7 +92,7 @@ def upgrade_user_table_with_copy(meta, migrate_engine, session):
     # different version of the user table
     meta2 = sql.MetaData()
     meta2.bind = migrate_engine
-    domain_table = sql.Table('domain', meta2, autoload=True)
+    sql.Table('domain', meta2, autoload=True)
     user_table = sql.Table(
         'user',
         meta2,
@@ -120,7 +118,7 @@ def upgrade_user_table_with_copy(meta, migrate_engine, session):
                          'extra': user.extra,
                          'password': user.password,
                          'enabled': user.enabled,
-                         'domain_id': DEFAULT_DOMAIN_ID})
+                         'domain_id': CONF.identity.default_domain_id})
     _enable_foreign_constraints(session, migrate_engine)
     session.execute('drop table temp_user;')
 
@@ -163,7 +161,7 @@ def upgrade_project_table_with_copy(meta, migrate_engine, session):
     # different version of the project table
     meta2 = sql.MetaData()
     meta2.bind = migrate_engine
-    domain_table = sql.Table('domain', meta2, autoload=True)
+    sql.Table('domain', meta2, autoload=True)
     project_table = sql.Table(
         'project',
         meta2,
@@ -189,7 +187,7 @@ def upgrade_project_table_with_copy(meta, migrate_engine, session):
                          'extra': project.extra,
                          'description': project.description,
                          'enabled': project.enabled,
-                         'domain_id': DEFAULT_DOMAIN_ID})
+                         'domain_id': CONF.identity.default_domain_id})
     _enable_foreign_constraints(session, migrate_engine)
     session.execute('drop table temp_project;')
 
@@ -326,13 +324,13 @@ def upgrade_user_table_with_col_create(meta, migrate_engine, session):
     # bat since any existing rows would cause an Integrity Error.
     # We therefore create it nullable, fill the column with the
     # default data and then set it to non nullable.
-    domain_table = sql.Table('domain', meta, autoload=True)
+    sql.Table('domain', meta, autoload=True)
     user_table = sql.Table('user', meta, autoload=True)
     user_table.create_column(
         sql.Column('domain_id', sql.String(64),
                    sql.ForeignKey('domain.id'), nullable=True))
     for user in session.query(user_table).all():
-        values = {'domain_id': DEFAULT_DOMAIN_ID}
+        values = {'domain_id': CONF.identity.default_domain_id}
         update = user_table.update().\
             where(user_table.c.id == user.id).\
             values(values)
@@ -346,6 +344,8 @@ def upgrade_user_table_with_col_create(meta, migrate_engine, session):
     session.execute('ALTER TABLE "user" ADD CONSTRAINT user_dom_name_unique '
                     'UNIQUE (domain_id, name);')
 
+    session.commit()
+
 
 def upgrade_project_table_with_col_create(meta, migrate_engine, session):
     # Create the domain_id column.  We want this to be not nullable
@@ -353,13 +353,13 @@ def upgrade_project_table_with_col_create(meta, migrate_engine, session):
     # bat since any existing rows would cause an Integrity Error.
     # We therefore create it nullable, fill the column with the
     # default data and then set it to non nullable.
-    domain_table = sql.Table('domain', meta, autoload=True)
+    sql.Table('domain', meta, autoload=True)
     project_table = sql.Table('project', meta, autoload=True)
     project_table.create_column(
         sql.Column('domain_id', sql.String(64),
                    sql.ForeignKey('domain.id'), nullable=True))
     for project in session.query(project_table).all():
-        values = {'domain_id': DEFAULT_DOMAIN_ID}
+        values = {'domain_id': CONF.identity.default_domain_id}
         update = project_table.update().\
             where(project_table.c.id == project.id).\
             values(values)
@@ -378,10 +378,12 @@ def downgrade_user_table_with_col_drop(meta, migrate_engine, session):
     # Revert uniqueness settings for the name attribute
     session.execute('ALTER TABLE "user" DROP CONSTRAINT '
                     'user_dom_name_unique;')
-    session.execute('ALTER TABLE "user" ADD UNIQUE (name);')
+    # specify the constraint name so it can be referenced later
+    session.execute('ALTER TABLE "user" ADD CONSTRAINT user_name_key '
+                    'UNIQUE (name);')
     session.commit()
     # And now go ahead an drop the domain_id column
-    domain_table = sql.Table('domain', meta, autoload=True)
+    sql.Table('domain', meta, autoload=True)
     user_table = sql.Table('user', meta, autoload=True)
     column = sql.Column('domain_id', sql.String(64),
                         sql.ForeignKey('domain.id'), nullable=False)
@@ -396,7 +398,7 @@ def downgrade_project_table_with_col_drop(meta, migrate_engine, session):
                     'UNIQUE (name);')
     session.commit()
     # And now go ahead an drop the domain_id column
-    domain_table = sql.Table('domain', meta, autoload=True)
+    sql.Table('domain', meta, autoload=True)
     project_table = sql.Table('project', meta, autoload=True)
     column = sql.Column('domain_id', sql.String(64),
                         sql.ForeignKey('domain.id'), nullable=False)
