@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2013 OpenStack LLC
+# Copyright 2013 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,12 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-
 import sqlalchemy
 from sqlalchemy import exc
-from sqlalchemy.orm import sessionmaker
-
-from keystone import config
 
 
 def downgrade_token_table_with_column_drop(meta, migrate_engine):
