@@ -12,32 +12,28 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-"""Main entry point into this Example service."""
-
-from oslo_log import log
 
 from keystone.common import dependency
 from keystone.common import manager
+from keystone import config
 from keystone import exception
-from keystone.i18n import _LI
-from keystone import notifications
+from keystone.openstack.common.gettextutils import _
+from keystone.openstack.common import log
 
 
+CONF = config.CONF
 LOG = log.getLogger(__name__)
 
 
-@notifications.listener  # NOTE(dstanek): only needed if using event_callbacks
 @dependency.provider('example_api')
 class ExampleManager(manager.Manager):
-    """Default pivot point for this Example backend.
+    """Example Manager.
 
     See :mod:`keystone.common.manager.Manager` for more details on
     how this dynamically calls the backend.
 
     """
 
-    driver_namespace = 'keystone.example'
-
     def __init__(self):
         # The following is an example of event callbacks. In this setup,
         # ExampleManager's data model is depended on project's data model.
@@ -50,34 +46,33 @@ class ExampleManager(manager.Manager):
         # project_created_callback will be invoked whenever a new project is
         # created.
 
-        # This information is used when the @notifications.listener decorator
-        # acts on the class.
+        # This information is used when the @dependency.provider decorator acts
+        # on the class.
         self.event_callbacks = {
-            notifications.ACTIONS.deleted: {
-                'project': [self.project_deleted_callback],
-            },
-            notifications.ACTIONS.created: {
-                'project': [self.project_created_callback],
-            },
-        }
+            'deleted': {
+                'project': [
+                    self.project_deleted_callback]},
+            'created': {
+                'project': [
+                    self.project_created_callback]}}
         super(ExampleManager, self).__init__(
             'keystone.contrib.example.core.ExampleDriver')
 
     def project_deleted_callback(self, service, resource_type, operation,
                                  payload):
         # The code below is merely an example.
-        msg = _LI('Received the following notification: service %(service)s, '
-                  'resource_type: %(resource_type)s, operation %(operation)s '
-                  'payload %(payload)s')
+        msg = _('Received the following notification: service %(service)s, '
+                'resource_type: %(resource_type)s, operation %(operation)s '
+                'payload %(payload)s')
         LOG.info(msg, {'service': service, 'resource_type': resource_type,
                        'operation': operation, 'payload': payload})
 
     def project_created_callback(self, service, resource_type, operation,
                                  payload):
         # The code below is merely an example.
-        msg = _LI('Received the following notification: service %(service)s, '
-                  'resource_type: %(resource_type)s, operation %(operation)s '
-                  'payload %(payload)s')
+        msg = _('Received the following notification: service %(service)s, '
+                'resource_type: %(resource_type)s, operation %(operation)s '
+                'payload %(payload)s')
         LOG.info(msg, {'service': service, 'resource_type': resource_type,
                        'operation': operation, 'payload': payload})
 
