@@ -12,25 +12,22 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-"""Main entry point into the OAuth1 service."""
+"""Extensions supporting OAuth1."""
 
 from __future__ import absolute_import
 
 import abc
-import string
-import uuid
 
 import oauthlib.common
 from oauthlib import oauth1
-from oslo_config import cfg
-from oslo_log import log
 import six
+import uuid
 
 from keystone.common import dependency
 from keystone.common import extension
 from keystone.common import manager
+from keystone import config
 from keystone import exception
-from keystone.i18n import _LE
 from keystone import notifications
 
 
@@ -42,11 +39,6 @@ AuthorizationEndpoint = oauth1.AuthorizationEndpoint
 SIG_HMAC = oauth1.SIGNATURE_HMAC
 RequestTokenEndpoint = oauth1.RequestTokenEndpoint
 oRequest = oauthlib.common.Request
-# The characters used to generate verifiers are limited to alphanumerical
-# values for ease of manual entry. Commonly confused characters are omitted.
-VERIFIER_CHARS = string.ascii_letters + string.digits
-CONFUSED_CHARS = 'jiIl1oO0'
-VERIFIER_CHARS = ''.join(c for c in VERIFIER_CHARS if c not in CONFUSED_CHARS)
 
 
 class Token(object):
@@ -59,8 +51,7 @@ class Token(object):
         self.verifier = verifier
 
 
-CONF = cfg.CONF
-LOG = log.getLogger(__name__)
+CONF = config.CONF
 
 
 def token_generator(*args, **kwargs):
@@ -132,15 +123,11 @@ def get_oauth_headers(headers):
         params = oauth1.rfc5849.utils.parse_authorization_header(auth_header)
         parameters.update(dict(params))
         return parameters
-    else:
-        msg = _LE('Cannot retrieve Authorization headers')
-        LOG.error(msg)
-        raise exception.OAuthHeadersMissingError()
 
 
 def extract_non_oauth_params(query_string):
     params = oauthlib.common.extract_params(query_string)
-    return {k: v for k, v in params if not k.startswith('oauth_')}
+    return dict([(k, v) for k, v in params if not k.startswith('oauth_')])
 
 
 @dependency.provider('oauth_api')
@@ -151,9 +138,6 @@ class Manager(manager.Manager):
     dynamically calls the backend.
 
     """
-
-    driver_namespace = 'keystone.oauth1'
-
     _ACCESS_TOKEN = "OS-OAUTH1:access_token"
     _REQUEST_TOKEN = "OS-OAUTH1:request_token"
     _CONSUMER = "OS-OAUTH1:consumer"
@@ -161,45 +145,36 @@ class Manager(manager.Manager):
     def __init__(self):
         super(Manager, self).__init__(CONF.oauth1.driver)
 
-    def create_consumer(self, consumer_ref, initiator=None):
-        ret = self.driver.create_consumer(consumer_ref)
-        notifications.Audit.created(self._CONSUMER, ret['id'], initiator)
-        return ret
+    @notifications.created(_CONSUMER)
+    def create_consumer(self, consumer_ref):
+        return self.driver.create_consumer(consumer_ref)
 
-    def update_consumer(self, consumer_id, consumer_ref, initiator=None):
-        ret = self.driver.update_consumer(consumer_id, consumer_ref)
-        notifications.Audit.updated(self._CONSUMER, consumer_id, initiator)
-        return ret
+    @notifications.updated(_CONSUMER)
+    def update_consumer(self, consumer_id, consumer_ref):
+        return self.driver.update_consumer(consumer_id, consumer_ref)
 
-    def delete_consumer(self, consumer_id, initiator=None):
-        ret = self.driver.delete_consumer(consumer_id)
-        notifications.Audit.deleted(self._CONSUMER, consumer_id, initiator)
-        return ret
+    @notifications.deleted(_CONSUMER)
+    def delete_consumer(self, consumer_id):
+        return self.driver.delete_consumer(consumer_id)
 
-    def create_access_token(self, request_id, access_token_duration,
-                            initiator=None):
-        ret = self.driver.create_access_token(request_id,
-                                              access_token_duration)
-        notifications.Audit.created(self._ACCESS_TOKEN, ret['id'], initiator)
-        return ret
+    @notifications.created(_ACCESS_TOKEN)
+    def create_access_token(self, request_id, access_token_duration):
+        return self.driver.create_access_token(request_id,
+                                               access_token_duration)
 
-    def delete_access_token(self, user_id, access_token_id, initiator=None):
-        ret = self.driver.delete_access_token(user_id, access_token_id)
-        notifications.Audit.deleted(self._ACCESS_TOKEN, access_token_id,
-                                    initiator)
-        return ret
+    @notifications.deleted(_ACCESS_TOKEN, resource_id_arg_index=2)
+    def delete_access_token(self, user_id, access_token_id):
+        return self.driver.delete_access_token(user_id, access_token_id)
 
+    @notifications.created(_REQUEST_TOKEN, resource_id_arg_index=2)
     def create_request_token(self, consumer_id, requested_project,
-                             request_token_duration, initiator=None):
-        ret = self.driver.create_request_token(
+                             request_token_duration):
+        return self.driver.create_request_token(
             consumer_id, requested_project, request_token_duration)
-        notifications.Audit.created(self._REQUEST_TOKEN, ret['id'],
-                                    initiator)
-        return ret
 
 
 @six.add_metaclass(abc.ABCMeta)
-class Oauth1DriverV8(object):
+class Driver(object):
     """Interface description for an OAuth1 driver."""
 
     @abc.abstractmethod
@@ -211,7 +186,7 @@ class Oauth1DriverV8(object):
         :returns: consumer_ref
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def update_consumer(self, consumer_id, consumer_ref):
@@ -224,7 +199,7 @@ class Oauth1DriverV8(object):
         :returns: consumer_ref
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def list_consumers(self):
@@ -233,7 +208,7 @@ class Oauth1DriverV8(object):
         :returns: list of consumers
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def get_consumer(self, consumer_id):
@@ -245,7 +220,7 @@ class Oauth1DriverV8(object):
         :returns: consumer_ref
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def get_consumer_with_secret(self, consumer_id):
@@ -260,7 +235,7 @@ class Oauth1DriverV8(object):
         :returns: consumer_ref
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def delete_consumer(self, consumer_id):
@@ -271,7 +246,7 @@ class Oauth1DriverV8(object):
         :returns: None.
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def list_access_tokens(self, user_id):
@@ -282,7 +257,7 @@ class Oauth1DriverV8(object):
         :returns: list of access tokens the user has authorized
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def delete_access_token(self, user_id, access_token_id):
@@ -295,7 +270,7 @@ class Oauth1DriverV8(object):
         :returns: None
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def create_request_token(self, consumer_id, requested_project,
@@ -311,7 +286,7 @@ class Oauth1DriverV8(object):
         :returns: request_token_ref
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def get_request_token(self, request_token_id):
@@ -322,7 +297,7 @@ class Oauth1DriverV8(object):
         :returns: request_token_ref
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def get_access_token(self, access_token_id):
@@ -333,7 +308,7 @@ class Oauth1DriverV8(object):
         :returns: access_token_ref
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def authorize_request_token(self, request_id, user_id, role_ids):
@@ -348,7 +323,7 @@ class Oauth1DriverV8(object):
         :returns: verifier
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def create_access_token(self, request_id, access_token_duration):
@@ -361,7 +336,4 @@ class Oauth1DriverV8(object):
         :returns: access_token_ref
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
-
-
-Driver = manager.create_legacy_driver(Oauth1DriverV8)
+        raise exception.NotImplemented()
