@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -21,7 +19,8 @@ def upgrade(migrate_engine):
     meta = sql.MetaData()
     meta.bind = migrate_engine
     request_token_table = sql.Table('request_token', meta, autoload=True)
-    request_token_table.c.requested_roles.alter(name="role_ids", nullable=True)
+    request_token_table.c.requested_roles.alter(nullable=True)
+    request_token_table.c.requested_roles.alter(name="role_ids")
     access_token_table = sql.Table('access_token', meta, autoload=True)
     access_token_table.c.requested_roles.alter(name="role_ids")
 
@@ -30,7 +29,7 @@ def downgrade(migrate_engine):
     meta = sql.MetaData()
     meta.bind = migrate_engine
     request_token_table = sql.Table('request_token', meta, autoload=True)
-    request_token_table.c.role_ids.alter(name="requested_roles",
-                                         nullable=False)
+    request_token_table.c.role_ids.alter(nullable=False)
+    request_token_table.c.role_ids.alter(name="requested_roles")
     access_token_table = sql.Table('access_token', meta, autoload=True)
     access_token_table.c.role_ids.alter(name="requested_roles")
