@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -27,7 +25,7 @@ class OAuth1Extension(wsgi.ExtensionRouter):
     on behalf of that user. This is done using an oauth-similar flow and
     api.
 
-    The API looks like:
+    The API looks like::
 
       # Basic admin-only consumer crud
       POST /OS-OAUTH1/consumers
