@@ -10,20 +10,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from keystone.common import json_home
 from keystone.common import wsgi
 from keystone.contrib.revoke import controllers
 
 
-class RevokeExtension(wsgi.V3ExtensionRouter):
+class RevokeExtension(wsgi.ExtensionRouter):
 
     PATH_PREFIX = '/OS-REVOKE'
 
     def add_routes(self, mapper):
         revoke_controller = controllers.RevokeController()
-        self._add_resource(
-            mapper, revoke_controller,
-            path=self.PATH_PREFIX + '/events',
-            get_action='list_revoke_events',
-            rel=json_home.build_v3_extension_resource_relation(
-                'OS-REVOKE', '1.0', 'events'))
+        mapper.connect(self.PATH_PREFIX + '/events',
+                       controller=revoke_controller,
+                       action='list_revoke_events',
+                       conditions=dict(method=['GET']))
