@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -18,10 +16,10 @@ from keystone.common import extension
 from keystone.common import wsgi
 from keystone import config
 from keystone import exception
-from keystone.openstack.common import log as logging
+from keystone.openstack.common import log
 
 
-LOG = logging.getLogger(__name__)
+LOG = log.getLogger(__name__)
 CONF = config.CONF
 
 MEDIA_TYPE_JSON = 'application/vnd.openstack.identity-%s+json'
@@ -71,12 +69,10 @@ class Version(wsgi.Application):
 
         super(Version, self).__init__()
 
-    def _get_identity_url(self, version='v2.0'):
+    def _get_identity_url(self, context, version):
         """Returns a URL to keystone's own endpoint."""
-        url = CONF['%s_endpoint' % self.endpoint_url_type] % CONF
-        if url[-1] != '/':
-            url += '/'
-        return '%s%s/' % (url, version)
+        url = self.base_url(context, self.endpoint_url_type)
+        return '%s/%s/' % (url, version)
 
     def _get_versions_list(self, context):
         """The list of versions is dependent on the context."""
@@ -85,11 +81,11 @@ class Version(wsgi.Application):
             versions['v2.0'] = {
                 'id': 'v2.0',
                 'status': 'stable',
-                'updated': '2013-03-06T00:00:00Z',
+                'updated': '2014-04-17T00:00:00Z',
                 'links': [
                     {
                         'rel': 'self',
-                        'href': self._get_identity_url(version='v2.0'),
+                        'href': self._get_identity_url(context, 'v2.0'),
                     }, {
                         'rel': 'describedby',
                         'type': 'text/html',
@@ -122,7 +118,7 @@ class Version(wsgi.Application):
                 'links': [
                     {
                         'rel': 'self',
-                        'href': self._get_identity_url(version='v3'),
+                        'href': self._get_identity_url(context, 'v3'),
                     }
                 ],
                 'media-types': [
