@@ -22,6 +22,7 @@ from keystone.common import dependency
 from keystone.common import manager
 from keystone import config
 from keystone import exception
+from keystone.openstack.common.gettextutils import _
 from keystone.openstack.common import log
 
 
@@ -54,7 +55,7 @@ class Driver(object):
         :raises: keystone.exception.Conflict
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def list_credentials(self, **filters):
@@ -63,7 +64,7 @@ class Driver(object):
         :returns: a list of credential_refs or an empty list.
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def get_credential(self, credential_id):
@@ -73,7 +74,7 @@ class Driver(object):
         :raises: keystone.exception.CredentialNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def update_credential(self, credential_id, credential):
@@ -83,7 +84,7 @@ class Driver(object):
                  keystone.exception.Conflict
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def delete_credential(self, credential_id):
@@ -92,7 +93,7 @@ class Driver(object):
         :raises: keystone.exception.CredentialNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def delete_credentials_for_project(self, project_id):
@@ -116,5 +117,5 @@ class Driver(object):
                 try:
                     self.credential_api.delete_credential(cr['id'])
                 except exception.CredentialNotFound:
-                    LOG.debug('Deletion of credential is not required: %s',
+                    LOG.debug(_('Deletion of credential is not required: %s'),
                               cr['id'])
