@@ -11,4 +11,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from keystone.tests.ksfixtures.cache import Cache  # noqa
+from keystone.tests.ksfixtures.cache import Cache  # flake8: noqa
