@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,11 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import os
 import uuid
 
 from keystoneclient.contrib.ec2 import utils as ec2_utils
 
-from keystone.common import sql
 from keystone import config
 from keystone import tests
 from keystone.tests import test_keystoneclient
@@ -27,26 +25,16 @@ from keystone.tests import test_keystoneclient
 CONF = config.CONF
 
 
-class KcMasterSqlTestCase(test_keystoneclient.KcMasterTestCase, sql.Base):
-    def config(self, config_files):
-        super(KcMasterSqlTestCase, self).config([
-            tests.etcdir('keystone.conf.sample'),
-            tests.testsdir('test_overrides.conf'),
-            tests.testsdir('backend_sql.conf')])
-
-        self.load_backends()
-        self.engine = self.get_engine()
-        sql.ModelBase.metadata.create_all(bind=self.engine)
+class KcMasterSqlTestCase(test_keystoneclient.KcMasterTestCase):
+    def config_files(self):
+        config_files = super(KcMasterSqlTestCase, self).config_files()
+        config_files.append(tests.dirs.tests_conf('backend_sql.conf'))
+        return config_files
 
     def setUp(self):
         super(KcMasterSqlTestCase, self).setUp()
         self.default_client = self.get_client()
-
-    def tearDown(self):
-        sql.ModelBase.metadata.drop_all(bind=self.engine)
-        self.engine.dispose()
-        sql.set_global_engine(None)
-        super(KcMasterSqlTestCase, self).tearDown()
+        self.addCleanup(self.cleanup_instance('default_client'))
 
     def test_endpoint_crud(self):
         from keystoneclient import exceptions as client_exceptions
@@ -78,11 +66,11 @@ class KcMasterSqlTestCase(test_keystoneclient.KcMasterTestCase, sql.Base):
                                            adminurl=endpoint_adminurl,
                                            internalurl=endpoint_internalurl)
 
-        self.assertEquals(endpoint.region, endpoint_region)
-        self.assertEquals(endpoint.service_id, service.id)
-        self.assertEquals(endpoint.publicurl, endpoint_publicurl)
-        self.assertEquals(endpoint.internalurl, endpoint_internalurl)
-        self.assertEquals(endpoint.adminurl, endpoint_adminurl)
+        self.assertEqual(endpoint.region, endpoint_region)
+        self.assertEqual(endpoint.service_id, service.id)
+        self.assertEqual(endpoint.publicurl, endpoint_publicurl)
+        self.assertEqual(endpoint.internalurl, endpoint_internalurl)
+        self.assertEqual(endpoint.adminurl, endpoint_adminurl)
 
         client.endpoints.delete(id=endpoint.id)
         self.assertRaises(client_exceptions.NotFound, client.endpoints.delete,
@@ -122,7 +110,7 @@ class KcMasterSqlTestCase(test_keystoneclient.KcMasterTestCase, sql.Base):
 
     def test_ec2_auth_success_trust(self):
         # Add "other" role user_foo and create trust delegating it to user_two
-        self.identity_api.add_role_to_user_and_project(
+        self.assignment_api.add_role_to_user_and_project(
             self.user_foo['id'],
             self.tenant_bar['id'],
             self.role_other['id'])
@@ -168,20 +156,20 @@ class KcMasterSqlTestCase(test_keystoneclient.KcMasterTestCase, sql.Base):
 
     def test_ec2_credential_crud(self):
         creds = self.default_client.ec2.list(user_id=self.user_foo['id'])
-        self.assertEquals(creds, [])
+        self.assertEqual(creds, [])
 
         cred = self.default_client.ec2.create(user_id=self.user_foo['id'],
                                               tenant_id=self.tenant_bar['id'])
         creds = self.default_client.ec2.list(user_id=self.user_foo['id'])
-        self.assertEquals(creds, [cred])
+        self.assertEqual(creds, [cred])
         got = self.default_client.ec2.get(user_id=self.user_foo['id'],
                                           access=cred.access)
-        self.assertEquals(cred, got)
+        self.assertEqual(cred, got)
 
         self.default_client.ec2.delete(user_id=self.user_foo['id'],
                                        access=cred.access)
         creds = self.default_client.ec2.list(user_id=self.user_foo['id'])
-        self.assertEquals(creds, [])
+        self.assertEqual(creds, [])
 
     def test_ec2_credential_crud_non_admin(self):
         na_client = self.get_client(self.user_two)
@@ -215,10 +203,10 @@ class KcMasterSqlTestCase(test_keystoneclient.KcMasterTestCase, sql.Base):
         cred_4 = two.ec2.create(user_id=self.user_two['id'],
                                 tenant_id=self.tenant_bar['id'])
         creds = self.default_client.ec2.list(user_id=self.user_foo['id'])
-        self.assertEquals(len(creds), 3)
-        self.assertEquals(sorted([cred_1, cred_2, cred_3],
-                                 key=lambda x: x.access),
-                          sorted(creds, key=lambda x: x.access))
+        self.assertEqual(len(creds), 3)
+        self.assertEqual(sorted([cred_1, cred_2, cred_3],
+                                key=lambda x: x.access),
+                         sorted(creds, key=lambda x: x.access))
         self.assertNotIn(cred_4, creds)
 
     def test_ec2_credentials_create_404(self):
@@ -334,20 +322,20 @@ class KcMasterSqlTestCase(test_keystoneclient.KcMasterTestCase, sql.Base):
             blob=policy_blob,
             type=policy_type,
             endpoint=endpoint.id)
-        self.assertEquals(policy_blob, policy.policy)
-        self.assertEquals(policy_type, policy.type)
-        self.assertEquals(endpoint.id, policy.endpoint_id)
+        self.assertEqual(policy_blob, policy.policy)
+        self.assertEqual(policy_type, policy.type)
+        self.assertEqual(endpoint.id, policy.endpoint_id)
 
         policy = client.policies.get(policy=policy.id)
-        self.assertEquals(policy_blob, policy.policy)
-        self.assertEquals(policy_type, policy.type)
-        self.assertEquals(endpoint.id, policy.endpoint_id)
+        self.assertEqual(policy_blob, policy.policy)
+        self.assertEqual(policy_type, policy.type)
+        self.assertEqual(endpoint.id, policy.endpoint_id)
 
         endpoints = [x for x in client.endpoints.list() if x.id == endpoint.id]
         endpoint = endpoints[0]
-        self.assertEquals(policy_blob, policy.policy)
-        self.assertEquals(policy_type, policy.type)
-        self.assertEquals(endpoint.id, policy.endpoint_id)
+        self.assertEqual(policy_blob, policy.policy)
+        self.assertEqual(policy_type, policy.type)
+        self.assertEqual(endpoint.id, policy.endpoint_id)
 
         # update
         policy_blob = uuid.uuid4().hex
@@ -366,9 +354,9 @@ class KcMasterSqlTestCase(test_keystoneclient.KcMasterTestCase, sql.Base):
             endpoint=endpoint.id)
 
         policy = client.policies.get(policy=policy.id)
-        self.assertEquals(policy_blob, policy.policy)
-        self.assertEquals(policy_type, policy.type)
-        self.assertEquals(endpoint.id, policy.endpoint_id)
+        self.assertEqual(policy_blob, policy.policy)
+        self.assertEqual(policy_type, policy.type)
+        self.assertEqual(endpoint.id, policy.endpoint_id)
 
         # delete
         client.policies.delete(policy=policy.id)
@@ -377,4 +365,19 @@ class KcMasterSqlTestCase(test_keystoneclient.KcMasterTestCase, sql.Base):
             client.policies.get,
             policy=policy.id)
         policies = [x for x in client.policies.list() if x.id == policy.id]
-        self.assertEquals(len(policies), 0)
+        self.assertEqual(len(policies), 0)
+
+
+class KcOptTestCase(KcMasterSqlTestCase):
+    # Set KSCTEST_PATH to the keystoneclient directory, then run this test.
+    #
+    # For example, to test your local keystoneclient,
+    #
+    # KSCTEST_PATH=/opt/stack/python-keystoneclient \
+    #  tox -e py27 test_keystoneclient_sql.KcOptTestCase
+
+    def setUp(self):
+        self.checkout_info = os.environ.get('KSCTEST_PATH')
+        if not self.checkout_info:
+            self.skip('Set KSCTEST_PATH env to test with local client')
+        super(KcOptTestCase, self).setUp()
