@@ -17,6 +17,7 @@ import ldap.modlist
 import subprocess
 import uuid
 
+from keystone.common import ldap as ldap_common
 from keystone import config
 from keystone import exception
 from keystone.identity.backends import ldap as identity_ldap
@@ -68,7 +69,7 @@ class LiveLDAPIdentity(test_backend_ldap.LDAPIdentity):
         create_object(CONF.ldap.role_tree_dn,
                       {'objectclass': 'organizationalUnit',
                        'ou': 'Roles'})
-        create_object(CONF.ldap.project_tree_dn,
+        create_object(CONF.ldap.tenant_tree_dn,
                       {'objectclass': 'organizationalUnit',
                        'ou': 'Projects'})
         create_object(CONF.ldap.group_tree_dn,
@@ -89,7 +90,7 @@ class LiveLDAPIdentity(test_backend_ldap.LDAPIdentity):
     def test_build_tree(self):
         """Regression test for building the tree names
         """
-        # logic is different from the fake backend.
+        #logic is different from the fake backend.
         user_api = identity_ldap.UserApi(CONF)
         self.assertTrue(user_api)
         self.assertEqual(user_api.tree_dn, CONF.ldap.user_tree_dn)
@@ -132,8 +133,44 @@ class LiveLDAPIdentity(test_backend_ldap.LDAPIdentity):
         user_ref = self.identity_api.get_user('alt_fake1')
         self.assertEqual(user_ref['id'], 'alt_fake1')
 
-    # FakeLDAP does not correctly process filters, so this test can only be
-    # run against a live LDAP server
+    def test_base_ldap_connection_deref_option(self):
+        deref = ldap_common.parse_deref('default')
+        ldap_wrapper = ldap_common.LdapWrapper(CONF.ldap.url,
+                                               CONF.ldap.page_size,
+                                               alias_dereferencing=deref)
+        self.assertEqual(ldap.get_option(ldap.OPT_DEREF),
+                         ldap_wrapper.conn.get_option(ldap.OPT_DEREF))
+
+        deref = ldap_common.parse_deref('always')
+        ldap_wrapper = ldap_common.LdapWrapper(CONF.ldap.url,
+                                               CONF.ldap.page_size,
+                                               alias_dereferencing=deref)
+        self.assertEqual(ldap.DEREF_ALWAYS,
+                         ldap_wrapper.conn.get_option(ldap.OPT_DEREF))
+
+        deref = ldap_common.parse_deref('finding')
+        ldap_wrapper = ldap_common.LdapWrapper(CONF.ldap.url,
+                                               CONF.ldap.page_size,
+                                               alias_dereferencing=deref)
+        self.assertEqual(ldap.DEREF_FINDING,
+                         ldap_wrapper.conn.get_option(ldap.OPT_DEREF))
+
+        deref = ldap_common.parse_deref('never')
+        ldap_wrapper = ldap_common.LdapWrapper(CONF.ldap.url,
+                                               CONF.ldap.page_size,
+                                               alias_dereferencing=deref)
+        self.assertEqual(ldap.DEREF_NEVER,
+                         ldap_wrapper.conn.get_option(ldap.OPT_DEREF))
+
+        deref = ldap_common.parse_deref('searching')
+        ldap_wrapper = ldap_common.LdapWrapper(CONF.ldap.url,
+                                               CONF.ldap.page_size,
+                                               alias_dereferencing=deref)
+        self.assertEqual(ldap.DEREF_SEARCHING,
+                         ldap_wrapper.conn.get_option(ldap.OPT_DEREF))
+
+    #FakeLDAP does not correctly process filters, so this test can only be run
+    #against a live LDAP server
     def test_list_groups_for_user_filtered(self):
         domain = self._get_domain_fixture()
         test_groups = []
@@ -142,10 +179,11 @@ class LiveLDAPIdentity(test_backend_ldap.LDAPIdentity):
         USER_COUNT = 2
 
         for x in range(0, USER_COUNT):
-            new_user = {'name': uuid.uuid4().hex, 'password': uuid.uuid4().hex,
-                        'enabled': True, 'domain_id': domain['id']}
-            new_user = self.identity_api.create_user(new_user)
+            new_user = {'id': uuid.uuid4().hex, 'name': uuid.uuid4().hex,
+                        'password': uuid.uuid4().hex, 'enabled': True,
+                        'domain_id': domain['id']}
             test_users.append(new_user)
+            self.identity_api.create_user(new_user['id'], new_user)
         positive_user = test_users[0]
         negative_user = test_users[1]
 
@@ -155,9 +193,10 @@ class LiveLDAPIdentity(test_backend_ldap.LDAPIdentity):
             self.assertEqual(len(group_refs), 0)
 
         for x in range(0, GROUP_COUNT):
-            new_group = {'domain_id': domain['id'],
+            new_group = {'id': uuid.uuid4().hex,
+                         'domain_id': domain['id'],
                          'name': uuid.uuid4().hex}
-            new_group = self.identity_api.create_group(new_group)
+            self.identity_api.create_group(new_group['id'], new_group)
             test_groups.append(new_group)
 
             group_refs = self.identity_api.list_groups_for_user(
