@@ -648,8 +648,7 @@ def create_v2_token():
     return {
         "access": {
             "token": {
-                "expires": timeutils.isotime(timeutils.utcnow() +
-                                             FUTURE_DELTA),
+                "expires": timeutils.isotime(CURRENT_DATE + FUTURE_DELTA),
                 "issued_at": "2013-05-21T00:02:43.941473Z",
                 "tenant": {
                     "enabled": True,
@@ -680,7 +679,7 @@ def create_v3_token():
     return {
         "token": {
             'methods': [],
-            "expires_at": timeutils.isotime(timeutils.utcnow() + FUTURE_DELTA),
+            "expires_at": timeutils.isotime(CURRENT_DATE + FUTURE_DELTA),
             "issued_at": "2013-05-21T00:02:43.941473Z",
         }
     }
@@ -722,18 +721,40 @@ class TestTokenProvider(tests.TestCase):
             token.provider.V3,
             self.token_provider_api.get_token_version(
                 SAMPLE_V3_TOKEN_WITH_EMBEDED_VERSION))
-        self.assertRaises(exception.UnsupportedTokenVersionException,
+        self.assertRaises(token.provider.UnsupportedTokenVersionException,
                           self.token_provider_api.get_token_version,
                           'bogus')
 
+    def test_token_format_provider_mismatch(self):
+        self.config_fixture.config(group='signing', token_format='UUID')
+        self.config_fixture.config(group='token',
+                                   provider=token.provider.PKI_PROVIDER)
+        self.assertRaises(exception.UnexpectedError, token.provider.Manager)
+
+        self.config_fixture.config(group='signing', token_format='PKI')
+        self.config_fixture.config(group='token',
+                                   provider=token.provider.UUID_PROVIDER)
+        self.assertRaises(exception.UnexpectedError, token.provider.Manager)
+
+        # should be OK as token_format and provider aligns
+        self.config_fixture.config(group='signing', token_format='PKI')
+        self.config_fixture.config(group='token',
+                                   provider=token.provider.PKI_PROVIDER)
+        token.provider.Manager()
+
+        self.config_fixture.config(group='signing', token_format='UUID')
+        self.config_fixture.config(group='token',
+                                   provider=token.provider.UUID_PROVIDER)
+        token.provider.Manager()
+
     def test_default_token_format(self):
-        self.assertEqual(token.provider.PKIZ_PROVIDER,
-                         token.provider.Manager.get_token_provider())
+        self.assertEqual(token.provider.Manager.get_token_provider(),
+                         token.provider.PKI_PROVIDER)
 
     def test_uuid_token_format_and_no_provider(self):
         self.config_fixture.config(group='signing', token_format='UUID')
-        self.assertEqual(token.provider.UUID_PROVIDER,
-                         token.provider.Manager.get_token_provider())
+        self.assertEqual(token.provider.Manager.get_token_provider(),
+                         token.provider.UUID_PROVIDER)
 
     def test_default_providers_without_token_format(self):
         self.config_fixture.config(group='token',
@@ -744,10 +765,6 @@ class TestTokenProvider(tests.TestCase):
                                    provider=token.provider.PKI_PROVIDER)
         token.provider.Manager()
 
-        self.config_fixture.config(group='token',
-                                   provider=token.provider.PKIZ_PROVIDER)
-        token.provider.Manager()
-
     def test_unsupported_token_format(self):
         self.config_fixture.config(group='signing', token_format='CUSTOM')
         self.assertRaises(exception.UnexpectedError,
@@ -756,33 +773,33 @@ class TestTokenProvider(tests.TestCase):
     def test_uuid_provider(self):
         self.config_fixture.config(group='token',
                                    provider=token.provider.UUID_PROVIDER)
-        self.assertEqual(token.provider.UUID_PROVIDER,
-                         token.provider.Manager.get_token_provider())
+        self.assertEqual(token.provider.Manager.get_token_provider(),
+                         token.provider.UUID_PROVIDER)
 
     def test_provider_override_token_format(self):
         self.config_fixture.config(
             group='token',
             provider='keystone.token.providers.pki.Test')
-        self.assertEqual('keystone.token.providers.pki.Test',
-                         token.provider.Manager.get_token_provider())
+        self.assertEqual(token.provider.Manager.get_token_provider(),
+                         'keystone.token.providers.pki.Test')
 
         self.config_fixture.config(group='signing', token_format='UUID')
         self.config_fixture.config(group='token',
                                    provider=token.provider.UUID_PROVIDER)
-        self.assertEqual(token.provider.UUID_PROVIDER,
-                         token.provider.Manager.get_token_provider())
+        self.assertEqual(token.provider.Manager.get_token_provider(),
+                         token.provider.UUID_PROVIDER)
 
         self.config_fixture.config(group='signing', token_format='PKI')
         self.config_fixture.config(group='token',
                                    provider=token.provider.PKI_PROVIDER)
-        self.assertEqual(token.provider.PKI_PROVIDER,
-                         token.provider.Manager.get_token_provider())
+        self.assertEqual(token.provider.Manager.get_token_provider(),
+                         token.provider.PKI_PROVIDER)
 
         self.config_fixture.config(group='signing', token_format='CUSTOM')
         self.config_fixture.config(group='token',
                                    provider='my.package.MyProvider')
-        self.assertRaises(exception.UnexpectedError,
-                          token.provider.Manager.get_token_provider)
+        self.assertEqual(token.provider.Manager.get_token_provider(),
+                         'my.package.MyProvider')
 
     def test_provider_token_expiration_validation(self):
         self.assertRaises(exception.TokenNotFound,
@@ -794,9 +811,11 @@ class TestTokenProvider(tests.TestCase):
         self.assertRaises(exception.TokenNotFound,
                           self.token_provider_api._is_valid_token,
                           SAMPLE_MALFORMED_TOKEN)
-        self.assertIsNone(
+        self.assertEqual(
+            None,
             self.token_provider_api._is_valid_token(create_v2_token()))
-        self.assertIsNone(
+        self.assertEqual(
+            None,
             self.token_provider_api._is_valid_token(create_v3_token()))
 
 
@@ -818,11 +837,10 @@ class TestTokenProviderOAuth1(tests.TestCase):
                           self.user_foo['id'], ['oauth1'])
 
 
-# NOTE(ayoung): renamed to avoid automatic test detection
-class PKIProviderTests(object):
+class TestPKIProvider(object):
 
     def setUp(self):
-        super(PKIProviderTests, self).setUp()
+        super(TestPKIProvider, self).setUp()
 
         from keystoneclient.common import cms
         self.cms = cms
@@ -853,7 +871,7 @@ class PKIProviderTests(object):
                           token_data)
 
 
-class TestPKIProviderWithEventlet(PKIProviderTests, tests.TestCase):
+class TestPKIProviderWithEventlet(TestPKIProvider, tests.TestCase):
 
     def setUp(self):
         # force keystoneclient.common.cms to use eventlet's subprocess
@@ -863,7 +881,7 @@ class TestPKIProviderWithEventlet(PKIProviderTests, tests.TestCase):
         super(TestPKIProviderWithEventlet, self).setUp()
 
 
-class TestPKIProviderWithStdlib(PKIProviderTests, tests.TestCase):
+class TestPKIProviderWithStdlib(TestPKIProvider, tests.TestCase):
 
     def setUp(self):
         # force keystoneclient.common.cms to use the stdlib subprocess
