@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -35,6 +33,7 @@ import os
 import time
 
 from keystone.common import utils
+from keystone import service
 from keystone import tests
 
 
@@ -62,6 +61,8 @@ def timezone(func):
 
 
 class UtilsTestCase(tests.TestCase):
+    OPTIONAL = object()
+
     def test_hash(self):
         password = 'right'
         wrong = 'wrongwrong'  # Two wrongs don't make a right
@@ -74,6 +75,47 @@ class UtilsTestCase(tests.TestCase):
         hashed = utils.hash_password(bigboy)
         self.assertTrue(utils.check_password(bigboy, hashed))
 
+    def _create_test_user(self, password=OPTIONAL):
+        user = {"name": "hthtest"}
+        if password is not self.OPTIONAL:
+            user['password'] = password
+
+        return user
+
+    def test_hash_user_password_without_password(self):
+        user = self._create_test_user()
+        hashed = utils.hash_user_password(user)
+        self.assertEqual(user, hashed)
+
+    def test_hash_user_password_with_null_password(self):
+        user = self._create_test_user(password=None)
+        hashed = utils.hash_user_password(user)
+        self.assertEqual(user, hashed)
+
+    def test_hash_user_password_with_empty_password(self):
+        password = ''
+        user = self._create_test_user(password=password)
+        user_hashed = utils.hash_user_password(user)
+        password_hashed = user_hashed['password']
+        self.assertTrue(utils.check_password(password, password_hashed))
+
+    def test_hash_ldap_user_password_without_password(self):
+        user = self._create_test_user()
+        hashed = utils.hash_ldap_user_password(user)
+        self.assertEqual(user, hashed)
+
+    def test_hash_ldap_user_password_with_null_password(self):
+        user = self._create_test_user(password=None)
+        hashed = utils.hash_ldap_user_password(user)
+        self.assertEqual(user, hashed)
+
+    def test_hash_ldap_user_password_with_empty_password(self):
+        password = ''
+        user = self._create_test_user(password=password)
+        user_hashed = utils.hash_ldap_user_password(user)
+        password_hashed = user_hashed['password']
+        self.assertTrue(utils.ldap_check_password(password, password_hashed))
+
     def test_hash_edge_cases(self):
         hashed = utils.hash_password('secret')
         self.assertFalse(utils.check_password('', hashed))
@@ -98,7 +140,7 @@ class UtilsTestCase(tests.TestCase):
         @timezone
         def _test_unixtime():
             epoch = utils.unixtime(dt)
-            self.assertEquals(epoch, epoch_ans, "TZ=%s" % TZ)
+            self.assertEqual(epoch, epoch_ans, "TZ=%s" % TZ)
 
         dt = datetime.datetime(1970, 1, 2, 3, 4, 56, 0)
         epoch_ans = 56 + 4 * 60 + 3 * 3600 + 86400
@@ -107,6 +149,16 @@ class UtilsTestCase(tests.TestCase):
             _test_unixtime()
 
 
+class ServiceHelperTests(tests.TestCase):
+
+    @service.fail_gracefully
+    def _do_test(self):
+        raise Exception("Test Exc")
+
+    def test_fail_gracefully(self):
+        self.assertRaises(tests.UnexpectedExit, self._do_test)
+
+
 class LimitingReaderTests(tests.TestCase):
 
     def test_read_default_value(self):
