@@ -17,50 +17,13 @@ import uuid
 
 from keystone import catalog
 from keystone import tests
-from keystone.tests.ksfixtures import database
+from keystone.tests import default_fixtures
 from keystone.tests import test_v3
 
 
 class CatalogTestCase(test_v3.RestfulTestCase):
     """Test service & endpoint CRUD."""
 
-    def test_get_catalog_project_scoped_token(self):
-        """Call ``GET /catalog`` with a project-scoped token."""
-        r = self.get(
-            '/catalog',
-            expected_status=200)
-        self.assertValidCatalogResponse(r)
-
-    def test_get_catalog_domain_scoped_token(self):
-        """Call ``GET /catalog`` with a domain-scoped token."""
-        # grant a domain role to a user
-        self.put(path='/domains/%s/users/%s/roles/%s' % (
-            self.domain['id'], self.user['id'], self.role['id']))
-
-        self.get(
-            '/catalog',
-            auth=self.build_authentication_request(
-                user_id=self.user['id'],
-                password=self.user['password'],
-                domain_id=self.domain['id']),
-            expected_status=403)
-
-    def test_get_catalog_unscoped_token(self):
-        """Call ``GET /catalog`` with an unscoped token."""
-        self.get(
-            '/catalog',
-            auth=self.build_authentication_request(
-                user_id=self.default_domain_user['id'],
-                password=self.default_domain_user['password']),
-            expected_status=403)
-
-    def test_get_catalog_no_token(self):
-        """Call ``GET /catalog`` without a token."""
-        self.get(
-            '/catalog',
-            noauth=True,
-            expected_status=401)
-
     # region crud tests
 
     def test_create_region_with_id(self):
@@ -115,17 +78,6 @@ class CatalogTestCase(test_v3.RestfulTestCase):
                 'region_id': ref['id']})
         self.assertValidRegionResponse(r, ref)
 
-    def test_create_region_with_empty_id(self):
-        """Call ``POST /regions`` with an empty ID in the request body."""
-        ref = self.new_region_ref()
-        ref['id'] = ''
-
-        r = self.post(
-            '/regions',
-            body={'region': ref}, expected_status=201)
-        self.assertValidRegionResponse(r, ref)
-        self.assertNotEmpty(r.result['region'].get('id'))
-
     def test_create_region_without_id(self):
         """Call ``POST /regions`` without an ID in the request body."""
         ref = self.new_region_ref()
@@ -140,76 +92,6 @@ class CatalogTestCase(test_v3.RestfulTestCase):
             expected_status=201)
         self.assertValidRegionResponse(r, ref)
 
-    def test_create_region_without_description(self):
-        """Call ``POST /regions`` without description in the request body."""
-        ref = self.new_region_ref()
-
-        del ref['description']
-
-        r = self.post(
-            '/regions',
-            body={'region': ref},
-            expected_status=201)
-        # Create the description in the reference to compare to since the
-        # response should now have a description, even though we didn't send
-        # it with the original reference.
-        ref['description'] = ''
-        self.assertValidRegionResponse(r, ref)
-
-    def test_create_regions_with_same_description_string(self):
-        """Call ``POST /regions`` with same description in the request bodies.
-        """
-        # NOTE(lbragstad): Make sure we can create two regions that have the
-        # same description.
-        ref1 = self.new_region_ref()
-        ref2 = self.new_region_ref()
-
-        region_desc = 'Some Region Description'
-
-        ref1['description'] = region_desc
-        ref2['description'] = region_desc
-
-        resp1 = self.post(
-            '/regions',
-            body={'region': ref1},
-            expected_status=201)
-        self.assertValidRegionResponse(resp1, ref1)
-
-        resp2 = self.post(
-            '/regions',
-            body={'region': ref2},
-            expected_status=201)
-        self.assertValidRegionResponse(resp2, ref2)
-
-    def test_create_regions_without_descriptions(self):
-        """Call ``POST /regions`` with no description in the request bodies.
-        """
-        # NOTE(lbragstad): Make sure we can create two regions that have
-        # no description in the request body. The description should be
-        # populated by Catalog Manager.
-        ref1 = self.new_region_ref()
-        ref2 = self.new_region_ref()
-
-        del ref1['description']
-        del ref2['description']
-
-        resp1 = self.post(
-            '/regions',
-            body={'region': ref1},
-            expected_status=201)
-
-        resp2 = self.post(
-            '/regions',
-            body={'region': ref2},
-            expected_status=201)
-        # Create the descriptions in the references to compare to since the
-        # responses should now have descriptions, even though we didn't send
-        # a description with the original references.
-        ref1['description'] = ''
-        ref2['description'] = ''
-        self.assertValidRegionResponse(resp1, ref1)
-        self.assertValidRegionResponse(resp2, ref2)
-
     def test_create_region_with_conflicting_ids(self):
         """Call ``PUT /regions/{region_id}`` with conflicting region IDs."""
         # the region ref is created with an ID
@@ -406,6 +288,9 @@ class CatalogTestCase(test_v3.RestfulTestCase):
             body={'endpoint': ref},
             expected_status=400)
 
+    def assertValidErrorResponse(self, response):
+        self.assertTrue(response.status_code in [400, 409])
+
     def test_create_endpoint_400(self):
         """Call ``POST /endpoints``."""
         ref = self.new_endpoint_ref(service_id=self.service_id)
@@ -509,21 +394,21 @@ class CatalogTestCase(test_v3.RestfulTestCase):
         # test the endpoint on v3
         r = self.get('/endpoints')
         endpoints = self.assertValidEndpointListResponse(r)
-        self.assertEqual(1, len(endpoints))
+        self.assertEqual(len(endpoints), 1)
         endpoint_v3 = endpoints.pop()
 
-        # these attributes are identical between both APIs
-        self.assertEqual(ref['region'], endpoint_v3['region'])
-        self.assertEqual(ref['service_id'], endpoint_v3['service_id'])
-        self.assertEqual(ref['description'], endpoint_v3['description'])
+        # these attributes are identical between both API's
+        self.assertEqual(endpoint_v3['region'], ref['region'])
+        self.assertEqual(endpoint_v3['service_id'], ref['service_id'])
+        self.assertEqual(endpoint_v3['description'], ref['description'])
 
         # a v2 endpoint is not quite the same concept as a v3 endpoint, so they
         # receive different identifiers
         self.assertNotEqual(endpoint_v2['id'], endpoint_v3['id'])
 
         # v2 has a publicurl; v3 has a url + interface type
-        self.assertEqual(ref['publicurl'], endpoint_v3['url'])
-        self.assertEqual('public', endpoint_v3['interface'])
+        self.assertEqual(endpoint_v3['url'], ref['publicurl'])
+        self.assertEqual(endpoint_v3['interface'], 'public')
 
         # tests for bug 1152632 -- these attributes were being returned by v3
         self.assertNotIn('publicurl', endpoint_v3)
@@ -541,7 +426,9 @@ class TestCatalogAPISQL(tests.TestCase):
 
     def setUp(self):
         super(TestCatalogAPISQL, self).setUp()
-        self.useFixture(database.Database())
+        self.load_backends()
+        self.load_fixtures(default_fixtures)
+
         self.catalog_api = catalog.Manager()
 
         self.service_id = uuid.uuid4().hex
