@@ -19,11 +19,15 @@ import uuid
 
 from six.moves import urllib
 
+from keystone.common import sql
+from keystone.common.sql import migration_helpers
 from keystone import config
+from keystone import contrib
 from keystone.contrib import oauth1
 from keystone.contrib.oauth1 import controllers
-from keystone.contrib.oauth1 import core
 from keystone import exception
+from keystone.openstack.common.db.sqlalchemy import migration
+from keystone.openstack.common import importutils
 from keystone.openstack.common import jsonutils
 from keystone.tests import test_v3
 
@@ -38,6 +42,14 @@ class OAuth1Tests(test_v3.RestfulTestCase):
 
     CONSUMER_URL = '/OS-OAUTH1/consumers'
 
+    def setup_database(self):
+        super(OAuth1Tests, self).setup_database()
+        package_name = '.'.join((contrib.__name__, self.EXTENSION_NAME))
+        package = importutils.import_module(package_name)
+        abs_path = migration_helpers.find_migrate_repo(package)
+        migration.db_version_control(sql.get_engine(), abs_path)
+        migration.db_sync(sql.get_engine(), abs_path)
+
     def setUp(self):
         super(OAuth1Tests, self).setUp()
 
@@ -249,9 +261,7 @@ class OAuthFlowTests(OAuth1Tests):
 
         url, headers = self._create_request_token(self.consumer,
                                                   self.project_id)
-        content = self.post(
-            url, headers=headers,
-            response_content_type='application/x-www-urlformencoded')
+        content = self.post(url, headers=headers)
         credentials = urllib.parse.parse_qs(content.result)
         request_key = credentials['oauth_token'][0]
         request_secret = credentials['oauth_token_secret'][0]
@@ -262,15 +272,11 @@ class OAuthFlowTests(OAuth1Tests):
         body = {'roles': [{'id': self.role_id}]}
         resp = self.put(url, body=body, expected_status=200)
         self.verifier = resp.result['token']['oauth_verifier']
-        self.assertTrue(all(i in core.VERIFIER_CHARS for i in self.verifier))
-        self.assertEqual(8, len(self.verifier))
 
         self.request_token.set_verifier(self.verifier)
         url, headers = self._create_access_token(self.consumer,
                                                  self.request_token)
-        content = self.post(
-            url, headers=headers,
-            response_content_type='application/x-www-urlformencoded')
+        content = self.post(url, headers=headers)
         credentials = urllib.parse.parse_qs(content.result)
         access_key = credentials['oauth_token'][0]
         access_secret = credentials['oauth_token_secret'][0]
@@ -301,15 +307,12 @@ class AccessTokenCRUDTests(OAuthFlowTests):
 
     def test_get_single_access_token(self):
         self.test_oauth_flow()
-        url = '/users/%(user_id)s/OS-OAUTH1/access_tokens/%(key)s' % {
-              'user_id': self.user_id,
-              'key': self.access_token.key
-        }
-        resp = self.get(url)
+        resp = self.get('/users/%(user_id)s/OS-OAUTH1/access_tokens/%(key)s'
+                        % {'user_id': self.user_id,
+                           'key': self.access_token.key})
         entity = resp.result['access_token']
         self.assertEqual(entity['id'], self.access_token.key)
         self.assertEqual(entity['consumer_id'], self.consumer['key'])
-        self.assertEqual('http://localhost/v3' + url, entity['links']['self'])
 
     def test_get_access_token_dne(self):
         self.get('/users/%(user_id)s/OS-OAUTH1/access_tokens/%(key)s'
@@ -466,7 +469,7 @@ class AuthTokenTests(OAuthFlowTests):
     def test_token_chaining_is_not_allowed(self):
         self.test_oauth_flow()
 
-        # attempt to re-authenticate (token chain) with the given token
+        #attempt to re-authenticate (token chain) with the given token
         path = '/v3/auth/tokens/'
         auth_data = self.build_authentication_request(
             token=self.keystone_token_id)
@@ -503,8 +506,10 @@ class AuthTokenTests(OAuthFlowTests):
             user_id=self.user['id'],
             password=self.user['password'],
             trust_id=trust['id'])
+        r = self.post('/auth/tokens', body=auth_data)
 
-        return self.get_requested_token(auth_data)
+        trust_token = r.headers['X-Subject-Token']
+        return trust_token
 
     def _approve_request_token_url(self):
         consumer = self._create_single_consumer()
@@ -515,9 +520,7 @@ class AuthTokenTests(OAuthFlowTests):
 
         url, headers = self._create_request_token(self.consumer,
                                                   self.project_id)
-        content = self.post(
-            url, headers=headers,
-            response_content_type='application/x-www-urlformencoded')
+        content = self.post(url, headers=headers)
         credentials = urllib.parse.parse_qs(content.result)
         request_key = credentials['oauth_token'][0]
         request_secret = credentials['oauth_token_secret'][0]
@@ -596,9 +599,7 @@ class MaliciousOAuth1Tests(OAuth1Tests):
         consumer_secret = consumer['secret']
         consumer = {'key': consumer_id, 'secret': consumer_secret}
         url, headers = self._create_request_token(consumer, self.project_id)
-        self.post(
-            url, headers=headers,
-            response_content_type='application/x-www-urlformencoded')
+        self.post(url, headers=headers)
         url = self._authorize_request_token(uuid.uuid4().hex)
         body = {'roles': [{'id': self.role_id}]}
         self.put(url, body=body, expected_status=404)
@@ -610,9 +611,7 @@ class MaliciousOAuth1Tests(OAuth1Tests):
         consumer = {'key': consumer_id, 'secret': consumer_secret}
 
         url, headers = self._create_request_token(consumer, self.project_id)
-        content = self.post(
-            url, headers=headers,
-            response_content_type='application/x-www-urlformencoded')
+        content = self.post(url, headers=headers)
         credentials = urllib.parse.parse_qs(content.result)
         request_key = credentials['oauth_token'][0]
         request_secret = credentials['oauth_token_secret'][0]
@@ -635,9 +634,7 @@ class MaliciousOAuth1Tests(OAuth1Tests):
         consumer = {'key': consumer_id, 'secret': consumer_secret}
 
         url, headers = self._create_request_token(consumer, self.project_id)
-        content = self.post(
-            url, headers=headers,
-            response_content_type='application/x-www-urlformencoded')
+        content = self.post(url, headers=headers)
         credentials = urllib.parse.parse_qs(content.result)
         request_key = credentials['oauth_token'][0]
 
@@ -659,9 +656,7 @@ class MaliciousOAuth1Tests(OAuth1Tests):
 
         url, headers = self._create_request_token(self.consumer,
                                                   self.project_id)
-        content = self.post(
-            url, headers=headers,
-            response_content_type='application/x-www-urlformencoded')
+        content = self.post(url, headers=headers)
         credentials = urllib.parse.parse_qs(content.result)
         request_key = credentials['oauth_token'][0]
         request_secret = credentials['oauth_token_secret'][0]
@@ -682,9 +677,7 @@ class MaliciousOAuth1Tests(OAuth1Tests):
 
         url, headers = self._create_request_token(self.consumer,
                                                   self.project_id)
-        content = self.post(
-            url, headers=headers,
-            response_content_type='application/x-www-urlformencoded')
+        content = self.post(url, headers=headers)
         credentials = urllib.parse.parse_qs(content.result)
         request_key = credentials['oauth_token'][0]
         request_secret = credentials['oauth_token_secret'][0]
@@ -699,9 +692,7 @@ class MaliciousOAuth1Tests(OAuth1Tests):
         self.request_token.set_verifier(self.verifier)
         url, headers = self._create_access_token(self.consumer,
                                                  self.request_token)
-        content = self.post(
-            url, headers=headers,
-            response_content_type='application/x-www-urlformencoded')
+        content = self.post(url, headers=headers)
         credentials = urllib.parse.parse_qs(content.result)
         access_key = credentials['oauth_token'][0]
         access_secret = credentials['oauth_token_secret'][0]
