@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,11 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from keystone import tests
+import random
 
 from keystone import config
 from keystone import controllers
+from keystone.openstack.common.fixture import moxstubout
 from keystone.openstack.common import jsonutils
+from keystone import tests
+from keystone.tests import matchers
 
 
 CONF = config.CONF
@@ -55,7 +56,7 @@ v2_PDF_DESCRIPTION = {
 v2_EXPECTED_RESPONSE = {
     "id": "v2.0",
     "status": "stable",
-    "updated": "2013-03-06T00:00:00Z",
+    "updated": "2014-04-17T00:00:00Z",
     "links": [
         {
             "rel": "self",
@@ -117,8 +118,17 @@ class VersionTestCase(tests.TestCase):
         self.public_app = self.loadapp('keystone', 'main')
         self.admin_app = self.loadapp('keystone', 'admin')
 
-        self.public_server = self.serveapp('keystone', name='main')
-        self.admin_server = self.serveapp('keystone', name='admin')
+        self.config_fixture.config(
+            public_endpoint='http://localhost:%(public_port)d',
+            admin_endpoint='http://localhost:%(admin_port)d')
+
+        fixture = self.useFixture(moxstubout.MoxStubout())
+        self.stubs = fixture.stubs
+
+    def config_overrides(self):
+        super(VersionTestCase, self).config_overrides()
+        port = random.randint(10000, 30000)
+        self.config_fixture.config(public_port=port, admin_port=port)
 
     def _paste_in_port(self, response, port):
         for link in response['links']:
@@ -155,6 +165,25 @@ class VersionTestCase(tests.TestCase):
                     version, 'http://localhost:%s/v2.0/' % CONF.admin_port)
         self.assertEqual(data, expected)
 
+    def test_use_site_url_if_endpoint_unset(self):
+        self.config_fixture.config(public_endpoint=None, admin_endpoint=None)
+
+        for app in (self.public_app, self.admin_app):
+            client = self.client(app)
+            resp = client.get('/')
+            self.assertEqual(resp.status_int, 300)
+            data = jsonutils.loads(resp.body)
+            expected = VERSIONS_RESPONSE
+            for version in expected['versions']['values']:
+                # localhost happens to be the site url for tests
+                if version['id'] == 'v3.0':
+                    self._paste_in_port(
+                        version, 'http://localhost/v3/')
+                elif version['id'] == 'v2.0':
+                    self._paste_in_port(
+                        version, 'http://localhost/v2.0/')
+            self.assertEqual(data, expected)
+
     def test_public_version_v2(self):
         client = self.client(self.public_app)
         resp = client.get('/v2.0/')
@@ -175,6 +204,17 @@ class VersionTestCase(tests.TestCase):
                             'http://localhost:%s/v2.0/' % CONF.admin_port)
         self.assertEqual(data, expected)
 
+    def test_use_site_url_if_endpoint_unset_v2(self):
+        self.config_fixture.config(public_endpoint=None, admin_endpoint=None)
+        for app in (self.public_app, self.admin_app):
+            client = self.client(app)
+            resp = client.get('/v2.0/')
+            self.assertEqual(resp.status_int, 200)
+            data = jsonutils.loads(resp.body)
+            expected = v2_VERSION_RESPONSE
+            self._paste_in_port(expected['version'], 'http://localhost/v2.0/')
+            self.assertEqual(data, expected)
+
     def test_public_version_v3(self):
         client = self.client(self.public_app)
         resp = client.get('/v3/')
@@ -195,6 +235,17 @@ class VersionTestCase(tests.TestCase):
                             'http://localhost:%s/v3/' % CONF.admin_port)
         self.assertEqual(data, expected)
 
+    def test_use_site_url_if_endpoint_unset_v3(self):
+        self.config_fixture.config(public_endpoint=None, admin_endpoint=None)
+        for app in (self.public_app, self.admin_app):
+            client = self.client(app)
+            resp = client.get('/v3/')
+            self.assertEqual(resp.status_int, 200)
+            data = jsonutils.loads(resp.body)
+            expected = v3_VERSION_RESPONSE
+            self._paste_in_port(expected['version'], 'http://localhost/v3/')
+            self.assertEqual(data, expected)
+
     def test_v2_disabled(self):
         self.stubs.Set(controllers, '_VERSIONS', ['v3'])
         client = self.client(self.public_app)
@@ -264,9 +315,10 @@ class XmlVersionTestCase(tests.TestCase):
 
     DOC_INTRO = '<?xml version="1.0" encoding="UTF-8"?>'
     XML_NAMESPACE_ATTR = 'xmlns="http://docs.openstack.org/identity/api/v2.0"'
+    XML_NAMESPACE_V3 = 'xmlns="http://docs.openstack.org/identity/api/v3"'
 
     v2_VERSION_DATA = """
-<version %(v2_namespace)s status="stable" updated="2013-03-06T00:00:00Z"
+<version %(v2_namespace)s status="stable" updated="2014-04-17T00:00:00Z"
          id="v2.0">
   <media-types>
     <media-type base="application/json" type="application/\
@@ -308,7 +360,7 @@ vnd.openstack.identity-v3+xml"/>
 """
 
     v3_VERSION_RESPONSE = ((DOC_INTRO + v3_VERSION_DATA) %
-                           dict(v3_namespace=XML_NAMESPACE_ATTR))
+                           dict(v3_namespace=XML_NAMESPACE_V3))
 
     VERSIONS_RESPONSE = ((DOC_INTRO + """
 <versions %(namespace)s>
@@ -324,8 +376,17 @@ vnd.openstack.identity-v3+xml"/>
         self.public_app = self.loadapp('keystone', 'main')
         self.admin_app = self.loadapp('keystone', 'admin')
 
-        self.public_server = self.serveapp('keystone', name='main')
-        self.admin_server = self.serveapp('keystone', name='admin')
+        self.config_fixture.config(
+            public_endpoint='http://localhost:%(public_port)d',
+            admin_endpoint='http://localhost:%(admin_port)d')
+
+        fixture = self.useFixture(moxstubout.MoxStubout())
+        self.stubs = fixture.stubs
+
+    def config_overrides(self):
+        super(XmlVersionTestCase, self).config_overrides()
+        port = random.randint(10000, 30000)
+        self.config_fixture.config(public_port=port, admin_port=port)
 
     def test_public_versions(self):
         client = self.client(self.public_app)
@@ -333,7 +394,7 @@ vnd.openstack.identity-v3+xml"/>
         self.assertEqual(resp.status_int, 300)
         data = resp.body
         expected = self.VERSIONS_RESPONSE % dict(port=CONF.public_port)
-        self.assertEqualXML(data, expected)
+        self.assertThat(data, matchers.XMLEquals(expected))
 
     def test_admin_versions(self):
         client = self.client(self.admin_app)
@@ -341,7 +402,15 @@ vnd.openstack.identity-v3+xml"/>
         self.assertEqual(resp.status_int, 300)
         data = resp.body
         expected = self.VERSIONS_RESPONSE % dict(port=CONF.admin_port)
-        self.assertEqualXML(data, expected)
+        self.assertThat(data, matchers.XMLEquals(expected))
+
+    def test_use_site_url_if_endpoint_unset(self):
+        client = self.client(self.public_app)
+        resp = client.get('/', headers=self.REQUEST_HEADERS)
+        self.assertEqual(resp.status_int, 300)
+        data = resp.body
+        expected = self.VERSIONS_RESPONSE % dict(port=CONF.public_port)
+        self.assertThat(data, matchers.XMLEquals(expected))
 
     def test_public_version_v2(self):
         client = self.client(self.public_app)
@@ -349,7 +418,7 @@ vnd.openstack.identity-v3+xml"/>
         self.assertEqual(resp.status_int, 200)
         data = resp.body
         expected = self.v2_VERSION_RESPONSE % dict(port=CONF.public_port)
-        self.assertEqualXML(data, expected)
+        self.assertThat(data, matchers.XMLEquals(expected))
 
     def test_admin_version_v2(self):
         client = self.client(self.admin_app)
@@ -357,7 +426,7 @@ vnd.openstack.identity-v3+xml"/>
         self.assertEqual(resp.status_int, 200)
         data = resp.body
         expected = self.v2_VERSION_RESPONSE % dict(port=CONF.admin_port)
-        self.assertEqualXML(data, expected)
+        self.assertThat(data, matchers.XMLEquals(expected))
 
     def test_public_version_v3(self):
         client = self.client(self.public_app)
@@ -365,7 +434,7 @@ vnd.openstack.identity-v3+xml"/>
         self.assertEqual(resp.status_int, 200)
         data = resp.body
         expected = self.v3_VERSION_RESPONSE % dict(port=CONF.public_port)
-        self.assertEqualXML(data, expected)
+        self.assertThat(data, matchers.XMLEquals(expected))
 
     def test_admin_version_v3(self):
         client = self.client(self.public_app)
@@ -373,7 +442,7 @@ vnd.openstack.identity-v3+xml"/>
         self.assertEqual(resp.status_int, 200)
         data = resp.body
         expected = self.v3_VERSION_RESPONSE % dict(port=CONF.admin_port)
-        self.assertEqualXML(data, expected)
+        self.assertThat(data, matchers.XMLEquals(expected))
 
     def test_v2_disabled(self):
         self.stubs.Set(controllers, '_VERSIONS', ['v3'])
@@ -384,7 +453,7 @@ vnd.openstack.identity-v3+xml"/>
         self.assertEqual(resp.status_int, 200)
         data = resp.body
         expected = self.v3_VERSION_RESPONSE % dict(port=CONF.public_port)
-        self.assertEqualXML(data, expected)
+        self.assertThat(data, matchers.XMLEquals(expected))
 
         # only v3 information should be displayed by requests to /
         v3_only_response = ((self.DOC_INTRO + '<versions %(namespace)s>' +
@@ -396,7 +465,7 @@ vnd.openstack.identity-v3+xml"/>
         resp = client.get('/', headers=self.REQUEST_HEADERS)
         self.assertEqual(resp.status_int, 300)
         data = resp.body
-        self.assertEqualXML(data, v3_only_response)
+        self.assertThat(data, matchers.XMLEquals(v3_only_response))
 
     def test_v3_disabled(self):
         self.stubs.Set(controllers, '_VERSIONS', ['v2.0'])
@@ -407,7 +476,7 @@ vnd.openstack.identity-v3+xml"/>
         self.assertEqual(resp.status_int, 200)
         data = resp.body
         expected = self.v2_VERSION_RESPONSE % dict(port=CONF.public_port)
-        self.assertEqualXML(data, expected)
+        self.assertThat(data, matchers.XMLEquals(expected))
 
         # only v2 information should be displayed by requests to /
         v2_only_response = ((self.DOC_INTRO + '<versions %(namespace)s>' +
@@ -419,4 +488,4 @@ vnd.openstack.identity-v3+xml"/>
         resp = client.get('/', headers=self.REQUEST_HEADERS)
         self.assertEqual(resp.status_int, 300)
         data = resp.body
-        self.assertEqualXML(data, v2_only_response)
+        self.assertThat(data, matchers.XMLEquals(v2_only_response))
