@@ -22,8 +22,8 @@ from keystone.common import dependency
 from keystone.common import manager
 from keystone import config
 from keystone import exception
-from keystone.i18n import _
 from keystone import notifications
+from keystone.openstack.common.gettextutils import _
 from keystone.openstack.common import log
 
 
@@ -77,27 +77,27 @@ class Driver(object):
 
         :returns: a new trust
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def get_trust(self, trust_id):
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def list_trusts(self):
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def list_trusts_for_trustee(self, trustee):
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def list_trusts_for_trustor(self, trustor):
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def delete_trust(self, trust_id):
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def consume_use(self, trust_id):
@@ -107,4 +107,4 @@ class Driver(object):
         :raises: keystone.exception.TrustUseLimitReached,
                  keystone.exception.TrustNotFound
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
